yt.utilities.lib.image\_samplers module
=======================================

.. automodule:: yt.utilities.lib.image_samplers
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
